"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const event_hubs_1 = require("@azure/event-hubs");
const chalk = require('chalk');
async function reader(config) {
    const client = event_hubs_1.EventHubClient.createFromConnectionString(config.connection);
    const partitions = await client.getPartitionIds();
    let position;
    switch (config.position) {
        case 'start':
            position = event_hubs_1.EventPosition.fromStart();
            break;
        case 'end':
            position = event_hubs_1.EventPosition.fromEnd();
            break;
        case 'offset':
            position = event_hubs_1.EventPosition.fromOffset(config.offset);
            break;
        case 'sequence':
            position = event_hubs_1.EventPosition.fromSequenceNumber(config.sequence);
            break;
        default:
            console.error('Unknown position');
            return;
    }
    for (const p of partitions) {
        if (config.partitions !== 'all' && p !== config.partitions) {
            continue;
        }
        const pCopy = p;
        client.receive(p, (event) => {
            print(pCopy, event);
        }, (error) => {
            logerror(error);
        }, {
            eventPosition: position,
            consumerGroup: config.consumerGroup
        });
    }
    return Promise.resolve(client);
}
exports.reader = reader;
function print(partitionId, event) {
    console.log(chalk.bgBlue(`> Partition: ${partitionId}`));
    console.log(chalk.bgGreen(event.enqueuedTimeUtc));
    console.log(chalk.blue(`event.header`));
    console.log(chalk.yellow(JSON.stringify(event.header, null, 2)));
    console.log(chalk.blue(`event.applicationProperties`));
    console.log(chalk.yellow(JSON.stringify(event.applicationProperties, null, 2)));
    console.log(chalk.blue(`event.properties`));
    console.log(chalk.yellow(JSON.stringify(event.properties, null, 2)));
    console.log(chalk.blue(`event.annotations`));
    console.log(chalk.yellow(JSON.stringify(event.annotations, null, 2)));
    console.log(chalk.blue(`event.enqueuedTimeUtc`));
    console.log(chalk.blue(`event.body`));
    console.log(chalk.green(JSON.stringify(event.body, null, 2)));
    console.log();
}
function logerror(error) {
    console.log(error);
}
//# sourceMappingURL=reader.js.map